# Buffy Python Client API

## ::: buffy.buffypyclient.BuffyPyClient
    options:
      members:
        - create_request
      show_root_heading: True



### ::: buffy.buffypyclient.BuffyPyClient.Request
    :docstring:
    :members:
    options:
      show_root_heading: True



## ::: buffy.buffyserver.api.v1.models.RequestCacheConfiguration
    handler: python
    options:
        show_root_heading: true
        show_source: true

